package com.ruoyi.baseinfo.mapper;

import java.util.List;
import com.ruoyi.baseinfo.domain.BaseWorkingprocedureInfo;

/**
 * 工序基础信息Mapper接口
 * 
 * @author CaesarBao
 * @date 2020-10-22
 */
public interface BaseWorkingprocedureInfoMapper 
{
    /**
     * 查询工序基础信息
     * 
     * @param objid 工序基础信息ID
     * @return 工序基础信息
     */
    public BaseWorkingprocedureInfo selectBaseWorkingprocedureInfoById(Long objid);

    /**
     * 查询工序基础信息列表
     * 
     * @param baseWorkingprocedureInfo 工序基础信息
     * @return 工序基础信息集合
     */
    public List<BaseWorkingprocedureInfo> selectBaseWorkingprocedureInfoList(BaseWorkingprocedureInfo baseWorkingprocedureInfo);

    /**
     * 新增工序基础信息
     * 
     * @param baseWorkingprocedureInfo 工序基础信息
     * @return 结果
     */
    public int insertBaseWorkingprocedureInfo(BaseWorkingprocedureInfo baseWorkingprocedureInfo);

    /**
     * 修改工序基础信息
     * 
     * @param baseWorkingprocedureInfo 工序基础信息
     * @return 结果
     */
    public int updateBaseWorkingprocedureInfo(BaseWorkingprocedureInfo baseWorkingprocedureInfo);

    /**
     * 删除工序基础信息
     * 
     * @param objid 工序基础信息ID
     * @return 结果
     */
    public int deleteBaseWorkingprocedureInfoById(Long objid);

    /**
     * 批量删除工序基础信息
     * 
     * @param objids 需要删除的数据ID
     * @return 结果
     */
    public int deleteBaseWorkingprocedureInfoByIds(String[] objids);

    public List<BaseWorkingprocedureInfo> selectAddBaseWorkingprocedureInfoList();
}
